# Edit this configuration file to define what should be installed on
# your system. Help is available in the configuration.nix(5) man page, on
# https://search.nixos.org/options and in the NixOS manual (`nixos-help`).

{
  config,
  lib,
  pkgs,
  ...
}:

{
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
    ./disk-config.nix
  ];

  # Enable flakes
  nix.settings.experimental-features = [
    "nix-command"
    "flakes"
  ];

  nixpkgs.config.allowUnfree = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "biggerpi"; # Define your hostname.
  # Enable networkmanager
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/London";

  users.groups.media = {
    name = "media";
  };

  users.users.jellyfin.uid = null;
  users.users.jellyfin.group = "media";
  users.users.jellyfin.isSystemUser = true;

  services.jellyfin = {
    enable = true;
    configDir = "/srv/config/jellyfin";
    logDir = "/srv/logs/jellyfin";
    openFirewall = true;
    user = "jellyfin";
    group = "media";
  };

  # Define a user account. Don't forget to set a password with ‘passwd’. Please change the initialHashedPassword for each deployment to avoid a brute force attack on this password allowing login to the system before an actual password is set.
  users.users.blue = {
    isNormalUser = true;
    extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
    initialHashedPassword = "$y$j9T$TbW09JXLRpNJ924xc5JEf1$YNroqf2T7AUnVzKi933eLRUp/0Bez8itOeMYsLw9g3A";
    #      packages = with pkgs; [
    #        neovim
    #        tree
    #      ];
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIBqczzd/CZJMg+jmxqhl0NS7GTNymsddrxDXyTtoG9zo blue@gabbielaptop"
    ];
  };

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    wget
    neovim
    tree
  ];

  # Enable the OpenSSH daemon.
  services.openssh.enable = true;

  # This option defines the first version of NixOS you have installed on this particular machine,
  # and is used to maintain compatibility with application data (e.g. databases) created on older NixOS versions.
  #
  # Most users should NEVER change this value after the initial install, for any reason,
  # even if you've upgraded your system to a new NixOS release.
  #
  # This value does NOT affect the Nixpkgs version your packages and OS are pulled from,
  # so changing it will NOT upgrade your system - see https://nixos.org/manual/nixos/stable/#sec-upgrading for how
  # to actually do that.
  #
  # This value being lower than the current NixOS release does NOT mean your system is
  # out of date, out of support, or vulnerable.
  #
  # Do NOT change this value unless you have manually inspected all the changes it would make to your configuration,
  # and migrated your data accordingly.
  #
  # For more information, see `man configuration.nix` or https://nixos.org/manual/nixos/stable/options#opt-system.stateVersion .
  system.stateVersion = "24.05"; # Did you read the comment?

}
